#
# gSmile - emoticon manager
# 
# Copyright (C) 2005, Federico Pelloni <federico.pelloni@gmail.com>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#

"""
gSmile emoticons manager

Easily manage your emoticons, keep them ready for use in bulletin-boards
and e-mails.

Usage: gsmile [option(s)]

Options:
  -d ..., --database=...  use the specified database directory instead
                          of the default one (~/.gsmile/database/)
  -h, --help              show this help

Examples:
  gsmile                  start with default database ~/.gsmile/database
  gsmile -d /data/gsmile  use /data/gsmile as emoticon database
  
"""


__author__ = "Federico Pelloni (federico.pelloni@gmail.com)"
__version__ = "0.1"
__copyright__ = "Copyright (c) 2005 Federico Pelloni"
__license__ = "GNU General Public License version 2"




import sys
import gettext
import getopt
import os, os.path

from os import mkdir

gettext.install('gsmile')


try:
	import pygtk
	pygtk.require("2.0")
except:
	print _("ERROR: You need to install pyGTK version 2.5.0 or higher!")
	raise SystemExit


try:
	import gtk, gtk.glade
except ImportError:
	print _("You need to install pyGTK or GTK+2\n" \
			"or set your PYTHONPATH correctly.\n" \
			"try: export PYTHONPATH=\n" \
			"/usr/lib/python2.3/site-packages/\n" )
	raise SystemExit
	

if gtk.pygtk_version < (2,5,0):
    print _("ERROR: You need to install pyGTK version 2.5.0 or higher!")
    raise SystemExit


from shared import *


basedir = os.path.expanduser("~/.gsmile/")

if not os.path.isdir(basedir):

	mkdir(basedir)

dbdir = basedir + "database/"

	
try:          

	opts, args = getopt.getopt(sys.argv[1:], "hd:", ["help", "database="])
	
except getopt.GetoptError:

	print __doc__
	sys.exit(2)
	


for opt, arg in opts:

	if opt in ("-h", "--help"):
	
		print __doc__
		sys.exit()
		
	if opt in ("-d", "--database"):
	
		dbdir = os.path.normpath(arg)
		
def start():

	import gui
	import database
	import preferences

	pref = preferences.Preferences()
	tagmodes = preferences.TagModes()
	db	 = database.Database(dbdir)
	ui	 = gui.Gui()
	tray = gui.Tray()
	ui.load()
	 
	if dbdir == basedir + "database/" and not os.path.isdir(dbdir):

		mkdir(dbdir)
		db.build()

	db.start()


	try:
		if db.ok:
			ui.run()
		
		
	except KeyboardInterrupt:
		print _("gSmile: Ctrl+C intercepted, closing...")
		try: 
			ui.quit_program()
		except:
			print _("Unable to save database, recent changes may have gone lost.")
		sys.exit (0);
		

