#
# gSmile - emoticon manager
# 
# Copyright (C) 2005, Federico Pelloni <federico.pelloni@gmail.com>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#


from gsmile.shared import gglobals


class Folder:


	iter = None
	
	path = None
	

	def __init__(self, node, parent, folder_id):
	
		node.normalize()
	
		self.ref = node
		
		self.id = folder_id
		
		self.parent = parent
		
		self.emoticons = []
		
		self.subfolders = []
		
		if parent != None:
			self.parent.subfolders.append(self.id)
		
	
	
	def set_iter(self, iter):
	
		self.iter = iter
		
		if iter != None:
			self.path = gglobals.gui.folderstore.get_path(self.iter)
		
		
	
	def create_iter(self):
	
		self.iter = gglobals.gui.folderstore.append(self.parent.iter,\
					(self.id, self.get('name'), self.get('created')))
					
		self.path = gglobals.gui.folderstore.get_path(self.iter)
		
		
		
	def get(self, field):
	
		try:
			v = self.ref.getElementsByTagName(field)[0].firstChild.data.strip()
		except:
			raise _("ERROR: Retriving information from a non-existing field (InvalidFolderField)")
			
		return v
		
		
		
	def show(self):
	
		gglobals.gui.emotilist.clear()
		
		for i in self.emoticons:
			
			gglobals.db.emoticons[i].show()
			
			
			
	def set(self, field, value, storefield = -1):
	
		try:
			self.ref.getElementsByTagName(field)[0].firstChild.data = value
		except:
			raise _("ERROR: Setting a non-existing field (InvalidFolderField)")
			
			
		if storefield > -1:
		
			gglobals.gui.folderstore[self.path][storefield] = value
		

	
	
	
	
	def move_up(self):
	
		folder = self.iter
			
		path = gglobals.gui.folderstore.get_path(folder)
		path_prev = path[:-1] + (path[-1] - 1, )

		prev = gglobals.gui.folderstore.get_iter(path_prev)
		
		if prev == None:
			return
			
		folder_id = gglobals.gui.folderstore.get_value(folder, 0)
		
		if folder_id < 1:
			return
		
		folder_node = self.ref
		parent_node = folder_node.parentNode
		
		prev_node = folder_node.previousSibling
		
		while prev_node != None and prev_node.nodeName != 'folder':
			prev_node = prev_node.previousSibling
		
		if prev_node == None:
			return
			
		clone = folder_node.cloneNode(True)
			
		parent_node.removeChild(folder_node)
		
		self.ref = clone
		
		parent_node.insertBefore(clone, prev_node)
		
		gglobals.gui.folderstore.swap(prev, folder)
		
		return
	
		
	
	def move_down(self):
		"""Move the folder down a position"""
		
		folder = self.iter
		
		next = gglobals.gui.folderstore.iter_next(folder)
		
		if next == None:
			return
			
		folder_id = self.id
		
		if folder_id < 1:
			return
		
		folder_node = self.ref
		parent_node = self.parent.ref
		
		next_node = folder_node.nextSibling
		
		while next_node != None and next_node.nodeName != 'folder':
			next_node = next_node.nextSibling
		
		if next_node == None:
			return
			
		next_clone = next_node.cloneNode(True)
			
		parent_node.removeChild(next_node)
		
		parent_node.insertBefore(next_clone, folder_node)
		
		gglobals.gui.folderstore.swap(folder, next)
		
		return		
					
	
	
	def remove(self):
	
		self.parent.ref.removeChild(self.ref)
		
		self.ref.unlink()
		
		for e in self.emoticons:
			
			del gglobals.db.emoticons[e]
				
		del gglobals.db.folders[self.id]
		
		return True

	
	
	
