
import gtk
from gsmile import shared, gglobals
import dialog


def quit_program(widget = None, status = 0):

	shared.quit_program(status)
	


def show_about_dialog(widget = None):
	"""Show the about-dialog"""
	
	try:
		gui.aboutwin.show()
	except:
		gui.__init_about_dialog()
		gui.aboutwin.show()
			

		
def show_folder(folder):

	gui.emotilist.clear()
		
	if folder == None:
		
		gui.smallbuttons["folder"]["edit"].set_sensitive(False)
		gui.smallbuttons["folder"]["delete"].set_sensitive(False)
		gui.smallbuttons["emoticon"]["new"].set_sensitive(False)
		gui.smallbuttons["emoticon"]["edit"].set_sensitive(False)
		gui.smallbuttons["emoticon"]["delete"].set_sensitive(False)
		
		return
		
	gui.smallbuttons["emoticon"]["new"].set_sensitive(True)
	gui.smallbuttons["folder"]["edit"].set_sensitive(True)
	gui.smallbuttons["folder"]["delete"].set_sensitive(True)			
	
	folderid = gui.folderstore.get_value(folder, 0)

	db.show_folder(folderid)



def select_folder(widget, event):
	"""Callback for selecting a folder with mouse"""

	x, y = event.get_coords()
	
	epath = gui.folderlist.get_path_at_pos(int(x), int(y))
	
	if epath == None:
	
		gui.selectedfolder.unselect_all()
	
	
	if event.button == 3:
	
		gui.folderlist_menu.popup(None, None, None, event.button, event.get_time())
	



def unselect_folder(widget):

	gui.selectedfolder.unselect_all()





def update_folder_selection(sel):
	"""Callback for updating widgets on folder selection"""
	
	folder = sel.get_selected()[1]
	
	if folder == None:
	
		gui.emotilist.switch_drop(0)
		
		gui.fl_menu[0].set_sensitive(True)
		
		for i in range(1, 6):
			
			gui.fl_menu[i].set_sensitive(False)

		gui.smallbuttons["folder"]["edit"].set_sensitive(False)
		gui.smallbuttons["folder"]["delete"].set_sensitive(False)
		gui.smallbuttons["folder"]["up"].set_sensitive(False)
		gui.smallbuttons["folder"]["down"].set_sensitive(False)
		gui.smallbuttons["folder"]["unselect"].set_sensitive(False)
			
	else:
	
		gui.emotilist.switch_drop(1)
			
		gui.fl_menu[0].set_sensitive(True)
		gui.fl_menu[1].set_sensitive(True)
		gui.fl_menu[2].set_sensitive(True)
		gui.fl_menu[5].set_sensitive(True)
		gui.smallbuttons["folder"]["unselect"].set_sensitive(True)
		gui.smallbuttons["folder"]["edit"].set_sensitive(True)
		gui.smallbuttons["folder"]["delete"].set_sensitive(True)
		
		path = gui.folderstore.get_path(folder)
		
		if path[-1] > 0:
			up = True
		else:
			up = False
				
		if up:
			gui.fl_menu[3].set_sensitive(True)
			gui.smallbuttons["folder"]["up"].set_sensitive(True)
		else:
			gui.fl_menu[3].set_sensitive(False)
			gui.smallbuttons["folder"]["up"].set_sensitive(False)
			
			
		if gui.folderstore.iter_next(gui.folderstore.get_iter(path)) == None:
			gui.fl_menu[4].set_sensitive(False)
			gui.smallbuttons["folder"]["down"].set_sensitive(False)
		else:
			gui.fl_menu[4].set_sensitive(True)
			gui.smallbuttons["folder"]["down"].set_sensitive(True)
	
	
	show_folder(folder)



def new_folder(widget):

	parent = gui.selectedfolder.get_selected()[1]
		
	if parent == None:
		
		parent_id = 0
			
	else:
		
		parent_id = gui.folderstore.get_value(parent, 0)
		
	folder = db.new_folder(parent_id)

	if parent_id > 0:
	
		gui.folderlist.expand_row(gui.folderstore.get_path(parent), False)
	
	gui.folderlist.set_cursor_on_cell(gui.folderstore.get_path(folder.iter),
									  gui.foldercol, gui.cellrend, True)
									  


def delete_folder(widget):

	folder = gui.selectedfolder.get_selected()[1]
		
	if folder == None:
		
		return
			
	if dialog.question(_("Delete folder '%s'?") % gui.folderstore.get_value(folder, 1), \
		_("Are you sure you want to delete the folder and all the emoticons and the "\
		  "subfolders that it contains?")) \
		== gtk.RESPONSE_YES :
		
		folder_id = gui.folderstore.get_value(folder, 0)
			
		gui.folderstore.remove(folder)
			
		db.delete_folder(folder_id)
			
	else:
		
		return



def edit_folder(widget):

	selection = gui.selectedfolder.get_selected()[1]
		
	if selection == None:
	
		return

	gui.folderlist.set_cursor_on_cell(gui.folderstore.get_path(selection),
									  gui.foldercol, gui.cellrend, True)
											
	return



def update_folder(widget, path, new_text):

	folder_id = gui.folderstore.get_value(gui.folderstore.get_iter(path), 0)
		
	if folder_id < 1:
		
		return
	
	db.update_folder(folder_id, new_text)
	
	return



def move_folder_up(widget):

	folder = gui.selectedfolder.get_selected()[1]
		
	if folder == None:
		return
			
	folder_id = gui.folderstore.get_value(folder, 0)
		
	if folder_id < 1:
		return

	db.move_folder_up(folder_id)
	
	


def move_folder_down(widget):

	folder = gui.selectedfolder.get_selected()[1]
		
	if folder == None:
		
		return
			
	folder_id = gui.folderstore.get_value(folder, 0)
		
	if folder_id < 1:
		return

	db.move_folder_down(folder_id)




def new_emoticon(widget = None, url = ''):

	f = gui.selectedfolder.get_selected()[1]
		
	if f == None:
	
		return
		
	else:
	
		folder_id = gui.folderstore.get_value(f, 0)
	
	gui.emoticon_dialog.empty()
	gui.emoticon_dialog.set_action("Add")
	gui.emoticon_dialog.set_url(url)
	
	infos = gui.emoticon_dialog.run()
	
	gui.emoticon_dialog.empty()
	
	if infos == None:
	
		return
		
	db.new_emoticon(folder_id, infos)
	




def show_tagmode_info(widget):
	"""Show an info dialog about tagmode formatting"""
	
	
	dialog.info(_("Tag-mode hints"),
			 _("It is possible to use any string you may want as tag-mode.\n\n"\
			   "When writing a new tag-mode, keep in your mind that <b>{URL}</b>"\
			   " will be replaced with the emoticon URL.\n\nNothing more,"\
			   " nothing less."))
	
	return
	

			
def switched_page(widget, page, number):

	gui.emotilist.clear()
	
	if number == 1:
		# Top-10s page -- DISABLED FOR NOW --
		#self._cb_switched_top10()
		pass
		


def show_preferences(widget):

	gglobals.preferences_dialog.show()

