#
# gSmile - emoticon manager
# 
# Copyright (C) 2005, Federico Pelloni <federico.pelloni@gmail.com>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#

import urllib2
from os import tmpfile
from gtk import STOCK_MISSING_IMAGE, ICON_SIZE_LARGE_TOOLBAR,\
				RESPONSE_CANCEL, RESPONSE_OK
from gtk.gdk import PixbufLoader

from gsmile.shared import gglobals
from os.path import join


class emoticon_dialog:

	def __init__(self, glade):
	
		self.window = glade.get_widget("emoticon_dialog")
		self.window.set_icon_from_file(join(gglobals.pixmapdir, gglobals.logo))
		
		self.basetitle = "%s emoticon"
		self._titlew = glade.get_widget("emoticond_title")
		
		self.url = ""
		self._urlw = glade.get_widget("emoticond_url")
		self._urlw.connect("changed", lambda w: self.update_preview())
		
		self._previeww = glade.get_widget("emoticond_preview")
		self._previeww.set_from_stock(STOCK_MISSING_IMAGE,\
										  ICON_SIZE_LARGE_TOOLBAR)
										  
		
		self._cancelw = glade.get_widget("emoticond_cancel")
		self._okw = glade.get_widget("emoticond_ok")
		self._descrw = glade.get_widget("emoticond_descr")
		self._namew = glade.get_widget("emoticond_name")
		self._namew.connect("changed", lambda w: self._update_okwidget())
		
		self._cancelw.connect("clicked", lambda w: self.cancel())
		
		self._okw.set_sensitive(False)
		self._urlstatus = False
		
		gglobals.emoticon_dialog = self
		
		
		
	def set_action(self, action):
	
		title = self.basetitle % action
		
		self.window.set_title(title)
		self._titlew.set_markup("<span size=\"larger\" weight=\"bold\">%s</span>" %\
								title)
		
		
		
	def set_url(self, url):
	
		self.url = url
		
		self._urlw.set_text(self.url)
		
		self.update_preview()
	
		
	
	def update_preview(self):
	
		self.url = self._urlw.get_text()
		
		try:
			pixbuf = PixbufLoader()
			pixbuf.connect("area-prepared", self._cb_area_prepared)
			pixbuf.connect("area-updated", self._cb_area_updated)
			img = urllib2.urlopen(self.url)
			pixbuf.write(img.read())
			pixbuf.close()
			img.close()
			self._pixbuf = pixbuf.get_pixbuf()
			self._previeww.set_from_animation(pixbuf.get_animation())
			self._urlstatus = True
		except:
			self._previeww.set_from_stock(STOCK_MISSING_IMAGE,\
										  ICON_SIZE_LARGE_TOOLBAR)
			self._urlstatus = False
			
		self._update_okwidget()
										  
		return
	
	
	
	def empty(self):
	
		self._namew.set_text("")
		self._descrw.set_text("")
		self._urlw.set_text("")
		self._previeww.set_from_stock(STOCK_MISSING_IMAGE, ICON_SIZE_LARGE_TOOLBAR)
		self._titlew.set_text("")
		self.window.set_title("")
	
	
	def cancel(self):
	
		self.empty()
		self.window.response(RESPONSE_CANCEL)
		
	
		
	def run(self):
	
		#self.empty()
		self.update_preview()
		self._update_okwidget()

		
		r = self.window.run()
		
		if r == RESPONSE_OK:
		
			infos = { 
				"name" : 	self._namew.get_text(),
				"descr":	self._descrw.get_text(),
				"url"  :	self._urlw.get_text(),
				"pixbuf":	self._pixbuf
			}

			self.empty()
			self.window.hide()

			return infos
			
		else:
		
			self.cancel()
		
			self.window.hide()
			
			return None
			
		
		
		
	def close(self):
	
		pass
			
			
			
	def _cb_area_prepared(self, pbl):
	
		self._previeww.set_from_animation(pbl.get_animation())
		
	
	def _cb_area_updated(self, pbl, x, y, w, h):
	
		self._previeww.set_from_animation(pbl.get_animation())
		
		
	
	def _update_okwidget(self):
	
		if self._urlstatus and self._namew.get_text() != "":
		
			self._okw.set_sensitive(True)
			
		else:
		
			self._okw.set_sensitive(False)

