#
# gSmile - emoticon manager
# 
# Copyright (C) 2005, Federico Pelloni <federico.pelloni@gmail.com>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#

import gtk, gobject, gtk.gdk
from gsmile.shared import gglobals
import callbacks

class emotilist(gtk.IconView):


	def __init__(self):
		"""Initialize emoticons list"""
		
		self._model = gtk.ListStore(gobject.TYPE_INT, gobject.TYPE_STRING,\
									gtk.gdk.Pixbuf)
									
		gtk.IconView.__init__(self, self._model)
		
		self.set_text_column(1)
		
		self.set_pixbuf_column(2)
		
		self.set_orientation(gtk.ORIENTATION_VERTICAL)
		
		self.set_selection_mode(gtk.SELECTION_SINGLE)
		
		self._init_dragndrop()
		
		self.connect("selection-changed", lambda w: self._update_selection())
		
		self.clear()
		
		self.show()


	
		
	
	def _init_dragndrop(self):
		
		self._targets = [('text/plain', 0, 0)]
		
		self.connect("drag-data-received", self._cb_emoticon_indrop)
		
		self.connect("drag-begin", self._cb_emoticon_taken)
		
		self.connect("drag-data-get", self._cb_emoticon_outdrop)
		
		
		
	def switch_drop(self, status):
	
		if status == 1:
			self.drag_dest_set(gtk.DEST_DEFAULT_ALL, self._targets, gtk.gdk.ACTION_COPY)
			
		if status == 0:
			self.drag_dest_unset()
			
		self._switch_drag(status)
		
	
	
	def _switch_drag(self, status):
		
		if status == 1:
			self.drag_source_set(gtk.gdk.BUTTON1_MASK, self._targets,\
								 gtk.gdk.ACTION_COPY)
		
		if status == 0:
			self.drag_source_unset()
		
		
		
	def add(self, id, name, pb):

		try:
			
			e = (id, name, pb)
			r = self._model.append(e)
			
		except:
			
			r = None
		
		return r
		
		
		
		
	def remove(self, iter):
	
		self._model.remove(iter)
	
	
	
	def clear(self):
	
		self._model.clear()
	
	
		
	def get_selected(self):
	
		lst = self.get_selected_items()
		
		if lst != []:
	
			eid = self._model.get_value(\
					self._model.get_iter(lst[0]),\
					0\
				)
				
		else:
		
			return None
			
		
		if eid == None:
		
			return None
			
		else:
		
			e = gglobals.db.emoticons[eid]
		
			return e
			
	
		
	def _cb_emoticon_indrop(self, widget, context, x, y, data, info, time):
	
		if context.get_source_widget() == None:
		
			callbacks.new_emoticon(None, data.get_text())
			
		return
		
	
	
	def _cb_emoticon_taken(self, widget, context):
	
		sel = self.get_selected()
	
		if sel == None:
		
			widget.drag_source_set_icon_stock(gtk.STOCK_DIALOG_ERROR)
		
		else:
		
			pb = sel.get_pixbuf()
			widget.drag_source_set_icon_pixbuf(pb)
		
	
		
	def _cb_emoticon_outdrop(self, widget, context, data, y, z):
	
		sel = self.get_selected()
		
		if sel != None:
		
			try:
				
				sel.update_counter()
				txt = gglobals.tagmodes.current % sel.get("url")
				data.set_text(txt, -1)

				if gglobals.preferences.get('window', 'behaviour') == 'advanced' and \
				   gglobals.preferences.getboolean('advanced', 'autohide'):

						gglobals.gui.mainwindow.hide()
				
			except:
			
				pass
		
		
	
	def _update_selection(self):
	
		pass
		
	
