#
# gSmile - emoticon manager
# 
# Copyright (C) 2005, Federico Pelloni <federico.pelloni@gmail.com>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#


import gtk, gtk.glade, gobject
import emoticon_dialog, preferences_dialog, emotilist, dialog, aboutwin
from gsmile.shared import gglobals, quit_program
import callbacks
from os.path import join


class Gui:


	def __init__(self):
	
		if gglobals.localrun:
			gladefile = gglobals.glade
		else:
			gladefile	= join(gglobals.prefix, gglobals.gladedir, gglobals.glade)
		
		windowname	= "mainwindow"
		
		self.mainglade = gtk.glade.XML(gladefile);
		
		gglobals.gui = self
		
		from mainwindow import mainwindow
		
		self.mainwindow = mainwindow()
		

		


	def load(self):
		"""Load the glade file and init the gui"""
		

		self.build_tree ()
		self.emotilist = emotilist.emotilist()
		self.mainglade.get_widget("emotilist_place").add(self.emotilist)
		self.init_tagmodelist ()
		
		self.notebook = self.mainglade.get_widget("notebook1")
		
		# Disabled until I implement a good-working top10 function
		#self.init_top10list ()
		
		self.init_smallbuttons ()
	
		self.fl_menu = ( self.mainglade.get_widget("fm_new"),
						 self.mainglade.get_widget("fm_prop"),
						 self.mainglade.get_widget("fm_delete"),
				 		 self.mainglade.get_widget("fm_up"),
						 self.mainglade.get_widget("fm_down"),
						 self.mainglade.get_widget("fm_unselect") )
	
		
		self.folderlist_menu = self.mainglade.get_widget("folderlist_menu")
		
		self.emoticon_dialog = emoticon_dialog.emoticon_dialog(self.mainglade)
		
		self.preferences_dialog = preferences_dialog.preferences_dialog(self.mainglade)
		
		self.aboutwin = aboutwin.aboutwin()
		
		callbacks.gui = self
		callbacks.db = gglobals.db
		self.set_callbacks()				
		
		
	def set_callbacks(self):
		"""Set callbacks on widgets"""
		
		dic = {
			"gsmile_quit"				: callbacks.quit_program,
			"show_about_dialog"			: callbacks.show_about_dialog,
			"update_emotilist"			: callbacks.show_folder,
			"show_folderlist_menu"		: callbacks.select_folder,
			"new_folder"				: callbacks.new_folder,
			"delete_folder"				: callbacks.delete_folder,
			"edit_folder"				: callbacks.edit_folder,
			"move_folder_up"			: callbacks.move_folder_up,
			"move_folder_down"			: callbacks.move_folder_down,
			"new_emoticon"				: callbacks.new_emoticon,
			"show_tagmode_info"			: callbacks.show_tagmode_info,
			"unselect_folder"			: callbacks.unselect_folder,
			"show_pref_dialog"			: callbacks.show_preferences
		}
		
		self.mainglade.signal_autoconnect(dic)
		
		self.notebook.connect("switch-page", callbacks.switched_page)
		
		return
		
		
		
	
	def __init_about_dialog(self):
		"""Initialize the aboutwin (set the reference from the glade tree)"""
	
		self.aboutwin = self.mainglade.get_widget("aboutwin")
		
		
		
	
	def run(self):
		"""Show the main window and start the GTK mainloop"""
	
		self.mainwindow.start()
	
		gtk.main()
		
		
	def build_tree(self):
		"""Build the folder list tree"""
	
		self.folderlist = self.mainglade.get_widget("folderlist")
		
		self.folderstore = gtk.TreeStore(gobject.TYPE_INT, gobject.TYPE_STRING,\
										 gobject.TYPE_STRING)
		
		self.folderlist.set_model(self.folderstore)
		
		self.folderlist.set_search_column(0)

		self.selectedfolder = self.folderlist.get_selection()
		
		self.selectedfolder.set_mode(gtk.SELECTION_SINGLE)
		
		self.selectedfolder.connect('changed', callbacks.update_folder_selection)

		self.cellrend = gtk.CellRendererText()
		
		self.cellrend.set_property('editable', True)
		
		self.cellrend.connect('edited', callbacks.update_folder)
		
		self.foldercol = gtk.TreeViewColumn('Folder', self.cellrend, text=1)
		
		self.folderlist.append_column(self.foldercol)
		
		
	
	def received_emoticon(self, widget, drag_context, x, y, selection_data, info, time):
	
		url = selection_data.data
		
		gglobals.db.new_emoticon(url)
		
		
		
		
	def init_tagmodelist(self):
		"""Initialize tagmodes list"""
	
		self.tagmodelist = self.mainglade.get_widget("tagmodelist")
		
		self.tagmodelist.set_model(gglobals.tagmodes.store)
		self.tagmodelist.set_text_column(1)
		
		self.tagmodelist.connect('changed', gglobals.tagmodes.cb_changed_tagmode)
		
		try:
			self.tagmodelist.set_active(0)
		except:
			pass
	
		
#
#	--- Disabled Function ---
#	I must work on `do_top10` function of database module
#	
#	def init_top10list(self):
#		"""Initialize top10 list"""
#	
#		self.top10list_store = gtk.ListStore(gobject.TYPE_STRING)
#		self.top10list = self.mainglade.get_widget("top10_list")
#		self.top10list.set_model(self.top10list_store)
#		cell = gtk.CellRendererText()
#		self.top10list.pack_start(cell, True)
#		self.top10list.add_attribute(cell, 'text', 0)
#		
#		self.top10list.append_text(_("most used"))
#		self.top10list.append_text(_("most recently used"))
#		self.top10list.append_text(_("most recently added"))
#		
#		self.top10list.connect("changed", self._cb_switched_top10)
#		
		
		
	def init_smallbuttons(self):
		"""Initialize utility buttons (new, edit, delete)"""
	
		folder = { "new": self.mainglade.get_widget("btn_small_new_folder"),
				   "edit": self.mainglade.get_widget("btn_small_edit_folder"),
				   "delete": self.mainglade.get_widget("btn_small_delete_folder"),
                   "up": self.mainglade.get_widget("btn_small_up_folder"),
                   "down": self.mainglade.get_widget("btn_small_down_folder"),
                   "unselect": self.mainglade.get_widget("btn_small_unselect_folder")
				}

		emoticon = { "new": self.mainglade.get_widget("btn_small_new_emoticon"),
				   "edit": self.mainglade.get_widget("btn_small_edit_emoticon"),
				   "delete": self.mainglade.get_widget("btn_small_delete_emoticon") }
				   
		self.smallbuttons = { "folder": folder, "emoticon": emoticon }
		
	
	
#
#	--- Disabled Function ---
#	I must work on `do_top10` function of database module
#			
#	def _cb_switched_top10(self, combo = None):
#	
#		self.emotilist.clear()
#		mode = self.top10list.get_active_text()
#		gglobals.db.do_top10(mode)
#	
	
