#
# gSmile - emoticon manager
# 
# Copyright (C) 2005, Federico Pelloni <federico.pelloni@gmail.com>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#


from gsmile.shared import gglobals
import gtk, gtk.gdk
from os.path import join


class mainwindow:


	def __init__(self):
	
		self.window = gglobals.gui.mainglade.get_widget("mainwindow")
		
		self.hide()
		
		self.window.set_icon_from_file(join(gglobals.pixmapdir, gglobals.logo))
		
		self._left_bar = gglobals.gui.mainglade.get_widget("left_bar")
		self._left_bar.set_from_file(join(gglobals.pixmapdir, "left_bar.png"))
		
		try:
			windowmode = gglobals.preferences.get('window','behaviour')
		except:
			windowmode = "classic"
		
	
		self.set_mode(windowmode)
		
		self.set_position()
		
		
	
	def hide(self):
	
		self.window.hide()
		
		
	def show(self):
	
		self.window.show()
				
	
	def start(self):
	
		
		autoshow = gglobals.preferences.getboolean("advanced", "autoshow")
		
		if gglobals.flags["windowmode"] == "classic" or \
			(gglobals.flags["windowmode"] == "advanced" and autoshow):
			
			self.window.show()


	
	def set_mode(self, windowmode):
	
	
		if windowmode == 'advanced':
			
			try:
				showleftimg = gglobals.preferences.getboolean('advanced', 'left_image')
			except:
				showleftimg = True
				
			try:
				showwinbord = gglobals.preferences.getboolean('advanced', 'window_border')
			except:
				showwinbord = False
				
			try:
				skiptaskbar = gglobals.preferences.getboolean('advanced', 'skip_taskbar')
			except:
				skiptaskbar = True
				
			try:
				skippager = gglobals.preferences.getboolean('advanced', 'skip_pager')
			except:
				skippager = True
			
		else:
		
			windowmode = 'classic'
			showwinbord = True
			skiptaskbar = False
			skippager = False
			
			try:
				showleftimg = gglobals.preferences.getboolean('classic', 'left_image')
			except:
				showleftimg = False
		
		
		gglobals.flags["windowmode"] = windowmode
		
		
		self.set_left_bar(showleftimg)
		self.set_border(showwinbord)
		self.set_skip_taskbar(skiptaskbar)
		self.set_skip_pager(skippager)
		
	
	
	
	def set_left_bar(self, status):
	
		if status:
			self._left_bar.show()
			gglobals.flags["show_left_bar"] = True
		else:
			self._left_bar.hide()
			gglobals.flags["show_left_bar"] = False
			
			
			
	def set_skip_taskbar(self, status):
	
		self.window.set_property("skip-taskbar-hint", status)
		gglobals.flags["skip_taskbar"] = status
		
	
	
	def set_border(self, status):
	
		self.window.set_decorated(status)
		gglobals.flags["show_window_border"] = status
		
		
	def set_skip_pager(self, status):
	
		self.window.set_property("skip-pager-hint", status)
		gglobals.flags["skip_pager"] = status
	
	
	def set_position(self):
	
		
		if gglobals.flags["windowmode"] == "classic":
		
			self.window.set_position(gtk.WIN_POS_NONE)
	
	
		elif gglobals.flags["windowmode"] == "advanced":
	
			self.window.set_gravity(gtk.gdk.GRAVITY_NORTH_WEST)
				
			try:
				x = gglobals.preferences.getint('advanced', 'x')
			except:
				x = 0
					
			try:
				y = gglobals.preferences.getint('advanced', 'y')
			except:
				y = 0
					
			self.window.move(x, y)
							
		
			
		

