#
# gSmile - emoticon manager
# 
# Copyright (C) 2005, Federico Pelloni <federico.pelloni@gmail.com>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#


from gsmile.shared import gglobals
from gtk import RESPONSE_OK, RESPONSE_APPLY
from os.path import join


class preferences_dialog:

	def __init__(self, glade):
	
		self.window = glade.get_widget("pref_dialog")
		self.window.set_icon_from_file(join(gglobals.pixmapdir, gglobals.logo))
	
		gglobals.preferences_dialog = self
		
		w = {
			"radio_classic" : glade.get_widget("pref_wb_classic"),
			"box_classic"	: glade.get_widget("pref_wb_classic_box"),
			"classic_check_left_img": glade.get_widget("pref_wb_classic_left_image"),
			"radio_adv"		: glade.get_widget("pref_wb_advanced"),
			"box_adv"		: glade.get_widget("pref_wb_adv_box"),
			"autoshow"		: glade.get_widget("pref_wb_adv_autoshow"),
			"autohide"		: glade.get_widget("pref_wb_adv_autohide"),
			"adv_check_left_img" : glade.get_widget("pref_wb_adv_left_image"),
			"adv_check_borders" : glade.get_widget("pref_wb_adv_borders"),
			"adv_check_taskbar" : glade.get_widget("pref_wb_adv_taskbar"),
			"adv_check_pager" : glade.get_widget("pref_wb_adv_pager"),
			"tagmodelist"	: glade.get_widget("pref_tagmodeslist"),
		}
		
		self.widgets = w
		
		w["tagmodelist"].set_model(gglobals.tagmodes.store)
		
		self._set_callbacks()
	
	
	
	def _set_callbacks(self):
	
		self.widgets["radio_classic"].connect("toggled",\
					self._cb_switch_wb, "classic")
		self.widgets["radio_adv"].connect("toggled",\
					self._cb_switch_wb, "advanced")
		
	
	
	
		
	def show(self):
	
		self.switch_wb(gglobals.flags["windowmode"])
		
		self.update_checks()
	
		r = self.window.run()
		
		if r == RESPONSE_APPLY:
		
			self.apply()
			self.show()
			
		elif r == RESPONSE_OK:
		
			self.apply()
			self.window.hide()
		
		else:
		
			self.update_checks()
			self.window.hide()
		
		
	
	def switch_wb(self, mode):
	
		if mode == "classic":
		
			self.widgets["radio_classic"].set_active(True)
			self.widgets["radio_adv"].set_active(False)
		
		elif mode == "advanced":
		
			self.widgets["radio_adv"].set_active(True)
			self.widgets["radio_classic"].set_active(False)
			
		self._cb_switch_wb(None, mode)
		
		
	
	def _cb_switch_wb(self, w, mode):
	
		if mode == "classic":
		
			self.widgets["box_adv"].set_sensitive(False)
			self.widgets["box_classic"].set_sensitive(True)
			
		elif mode == "advanced":
		
			self.widgets["box_classic"].set_sensitive(False)
			self.widgets["box_adv"].set_sensitive(True)
			
			
		
				
	def update_checks(self, classic = True, advanced = True):
	
		if classic:
		
			try:
				status = gglobals.preferences.getboolean("classic", "left_image")
			except:
				status = False
				
			self.widgets["classic_check_left_img"].set_active(status)
				
				
		
		if advanced:
		
			try:
				status = gglobals.preferences.getboolean("advanced", "autoshow")
			except:
				status = False
			self.widgets["autoshow"].set_active(status)
			
			try:
				status = gglobals.preferences.getboolean("advanced", "autohide")
			except:
				status = True
			self.widgets["autohide"].set_active(status)
		
			try:
				status = gglobals.preferences.getboolean("advanced", "left_bar")
			except:
				status = True
			self.widgets["adv_check_left_img"].set_active(status)
			
			try:
				status = gglobals.preferences.getboolean("advanced", "skip_taskbar")
			except:
				status = True
			self.widgets["adv_check_taskbar"].set_active(status)
			
			try:
				status = gglobals.preferences.getboolean("advanced", "skip_pager")
			except:
				status = False
			self.widgets["adv_check_pager"].set_active(status)
			
			try:
				status = gglobals.preferences.getboolean("advanced", "window_border")
			except:
				status = False
			self.widgets["adv_check_borders"].set_active(status)



	def apply(self):
	
		if self.widgets["radio_classic"].get_active():
			wm = "classic"
		else:
			wm = "advanced"
		
		gglobals.preferences.set("classic", "left_image",\
			str(self.widgets["classic_check_left_img"].get_active()))
		gglobals.preferences.set("advanced", "autoshow", \
			str(self.widgets["autoshow"].get_active()))
		gglobals.preferences.set("advanced", "autohide", \
			str(self.widgets["autohide"].get_active()))
		gglobals.preferences.set("advanced", "left_image",\
			str(self.widgets["adv_check_left_img"].get_active()))
		gglobals.preferences.set("advanced", "window_border",\
			str(self.widgets["adv_check_borders"].get_active()))
		gglobals.preferences.set("advanced", "skip_taskbar",\
			str(self.widgets["adv_check_taskbar"].get_active()))
		gglobals.preferences.set("advanced", "skip_pager",\
			str(self.widgets["adv_check_pager"].get_active()))
			
		gglobals.preferences.set("window", "behaviour", wm)
		
		gglobals.gui.mainwindow.set_mode(wm)
		gglobals.gui.mainwindow.set_position()

	
			
